/* Panel (begin) */
    .panel_checkbox, .panel_mobile_button, .panel_mobile_button_close
    {
        display: none;
    }

    @media (max-width: 39.99em) {
        .panel_mobile_button {
            display: block;
            height: 40px;
            position: sticky;
            top: 0;
            background: #000;
            color: #fff;
            padding: 0 10px;
            line-height: 40px;
            cursor: pointer;
            z-index: 2;
        }
        .panel_checkbox:checked ~ .panel_mobile_button {
        }

        .panel_checkbox:checked ~ .panel .panel_mobile_button_close {
            display: block;
            height: 40px;
            position: absolute;
            top: 0;
            right: 10px;
            z-index: 3000;
            text-align: right;
            line-height: 40px;
            cursor: pointer;
        }
    }

    .panel_mobile_button span {
         position: relative;
         display: inline-block;
         width: 1em;
         height: 0.55em;
         margin-right: 0.3em;
         border-top: 0.1em solid #fff;
         border-bottom: 0.1em solid #fff;
    }

    .panel_mobile_button span:before {
         content: "";
         position: absolute;
         top: 0.25em;
         left: 0px;
         width: 100%;
         border-top: 0.1em solid #fff;
    }

    .panel_mobile_button_close span {
         position: relative;
         display: inline-block;
         width: 1em;
         height: 0.625em;
    }

    .panel_mobile_button_close span:before, .panel_mobile_button_close span:after {
         content: "";
         position: absolute;
         top: 0.2em;
         left: 0px;
         width: 100%;
         border-top: 0.1em solid #000;
    }

    .panel_mobile_button_close span:before {
        transform: rotate(45deg);
    }

    .panel_mobile_button_close span:after {
        transform: rotate(-45deg);
    }

    .panel
    {
        position: fixed;
        top: 0;
        width: 300px;
        height: 100%;
        background: #FFF;
        z-index: 200;
        font-family: "Helvetica Neue", "Arial", sans-serif;
        overflow-x: hidden;
        border-right: 1px #ccc solid;
        line-height: 1;
    }

    @media (max-width: 39.99em) {
        .panel
        {
            transition: left 0s ease-in-out;
            left: -100%;
            width: 100%;
            bottom: 0;
            visibility: hidden;
        }

        .panel_checkbox:checked ~ .panel {
            left: 0%;
            transition: left 0.3s ease-in-out;
            visibility: visible;
        }

        .panel_checkbox:checked ~ #bodyContent {
            visibility: hidden;
            display: none;
        }
    }

    .panel_tree .result,
    .panel_results .tree
    {
        display: none;
    }

    /* Header with search box (begin) */
        .panel .header
        {
            background: white url(../i/search.svg) no-repeat;
            background-position: 5px;
            box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.2);
            height: 40px;
            width: 300px;
            position: fixed;
            position: sticky;
            left: 0; top: 0;
            z-index: 300;
            overflow-x: hidden;
        }

        @media (max-width: 39.99em) {
            .panel .header
            {
                width: 100%;
            }
        }

        .panel .header input
        {
            border: 0;
            box-sizing: border-box;
            display: inline-block;
            font-size: 14px;
            height: 40px;
            width: 100%;
            padding: 0 5px;
            margin: 0;
            margin-left: 25px;
            outline: none;
        }

        @media (max-width: 39.99em) {
            .panel .header input
            {
                width: 70%;
                width: calc(100% - 100px);
                font-size: 16px;
            }
        }

    /* Header with search box (end) */


    /* Results (begin) */
        .panel .result
        {
            position: relative;
            bottom: 0;
            top: 0;
            left: 0;
            width: 100%;
            overflow-y: auto;
            overflow-x: hidden;
            z-index: 2;
        }

        .panel .result ul
        {
            font-size: 0.8em;
            width: 100%;
        }

        .panel .result ul li
        {
            height: 46px;
            overflow: hidden;
            padding: 4px 10px 0 10px;
            cursor: pointer;
            margin: 0;
        }

        .panel .result ul li:nth-child(2n) {
            background: #F0EFEF;
        }

        .panel .result ul li h1
        {
            font-size: 13px;
            font-weight: normal;
            color: #333;
            margin-top: 0;
            margin-bottom: 2px;
            white-space: nowrap;
        }

        .panel .result ul li p
        {
            font-size: 11px;
            color: #333;
            margin-bottom: 2px;
            white-space: nowrap;
        }

        .panel .result ul li h1 i,
        .panel .result ul li p.snippet
        {
            color: #777;
        }

        .panel .result ul li b
        {
            color: #000;
        }

        .panel .result ul li.current
        {
            background: #B61D1D;
        }

        .panel .result ul li.current h1,
        .panel .result ul li.current p
        {
            color: #D9D9D9;
        }

        .panel .result ul li.current h1 i,
        .panel .result ul li.current p.snippet
        {
            color: #ACACAC;
        }

        .panel .result ul li.current b
        {
            color: #FFF;
        }


        .panel .result ul li:hover,
        .panel .result ul li.selected
        {
            background: #d0d0d0;
        }

        .panel .result ul li.current:hover
        {
            background: #B61D1D;
        }

        .panel .result ul li .badge
        {
            margin-right: 0.4em;
            margin-left: -0.2em;
            padding: 0 0.2em;
            color: #000;
            border-radius: 3px;
        }

        .panel .result ul li .badge_1
        {
            background: #ACDBF4;
        }

        .panel .result ul li.current .badge_1
        {
            background: #97BFD7;
        }

        .panel .result ul li .badge_2
        {
            background: #ACF3C3;
        }

        .panel .result ul li.current .badge_2
        {
            background: #98D7AC;
        }

        .panel .result ul li .badge_3
        {
            background: #E0F3AC;
        }

        .panel .result ul li.current .badge_3
        {
            background: #C4D798;
        }

        .panel .result ul li .badge_4
        {
            background: #D7CA98;
        }

        .panel .result ul li.current .badge_4
        {
            background: #A6B0AC;
        }

        .panel .result ul li .badge_5
        {
            background: #F3C8AC;
        }

        .panel .result ul li.current .badge_5
        {
            background: #D7B198;
        }

        .panel .result ul li .badge_6
        {
            background: #F3ACC3;
        }

        .panel .result ul li.current .badge_6
        {
            background: #D798AB;
        }

    /* Results (end) */

    /* Tree (begin) */ /**/
        .panel .tree
        {
            background: white;
            position: relative;
            bottom: 0;
            left: 0;
            width: 100%;
            overflow-y: auto;
            overflow-x: hidden;
            z-index: 30;
        }

        .panel .tree ul:first-child
        {
            background: url(../i/tree_bg.svg);
            background-size: 1px 60px;
        }

        .panel .tree li
        {
            cursor: pointer;
            overflow: hidden;
            height: 30px;
            line-height: 100%;
            margin: 0;
        }


        .panel .tree li .content
        {
            padding-left: 18px;
            padding-top: 5px;
            height: 18px;
            overflow: hidden;
            position: relative;
        }

        .panel .tree li .icon
        {
            width: 10px;
            height: 9px;
            background: url(../i/arrow-down.svg);
            background-size: 10px;
            position: absolute;
            left: 1px;
            top: 8px;
            cursor: default;
        }

        .panel .tree li.closed .icon
        {
            background: url(../i/arrow-right.svg);
            background-size: 10px;
        }

        .panel .tree ul li h1
        {
            font-size: 13px;
            font-weight: normal;
            color: #000;
            margin-top: 0;
            margin-bottom: 2px;
            white-space: nowrap;
        }

        .panel .tree ul li p
        {
            font-size: 11px;
            color: #666;
            margin-bottom: 2px;
            white-space: nowrap;
        }

        .panel .tree ul li h1 i
        {
            color: #999;
            font-style: normal;
        }

        .panel .tree ul li.current h1 i
        {
            color: #CCC;
        }

        .panel .tree ul li.empty
        {
            cursor: text;
        }

        .panel .tree ul li.empty h1,
        .panel .tree ul li.empty p
        {
            color: #666;
            font-style: italic;
        }

        .panel .tree ul li.current
        {
            background: #B61D1D;
        }

        .panel .tree ul li.current .icon
        {
            background: url(../i/arrow-down-current.svg);
            background-size: 10px;
        }

        .panel .tree ul li.current.closed .icon
        {
            background: url(../i/arrow-right-current.svg);
            background-size: 10px;
        }

        .panel .tree ul li.current h1
        {
            color: #FFF;
        }

        .panel .tree ul li.current p
        {
            color: #CCC;
        }

        .panel .tree ul li.current.empty h1,
        .panel .tree ul li.current.empty p
        {
            color: #999;
        }

        .panel .tree ul li:hover
        {
            background: #d0d0d0;
        }

        .panel .tree ul li.current:hover
        {
            background: #B61D1D;
        }

        .panel .tree .stopper
        {
            display: none;
        }
    /* Tree (end) */ /**/

/* Panel (end) */
